pub struct GetFulfillmentPreviewRequest {
    pub marketplace_id: Option<String>,
    pub address: Box<Address>,
    pub items: Vec<GetFulfillmentPreviewItem>,
    pub shipping_speed_categories: Option<Vec<ShippingSpeedCategory>>,
    pub include_cod_fulfillment_preview: Option<bool>,
    pub include_delivery_windows: Option<bool>,
    pub feature_constraints: Option<Vec<FeatureSettings>>,
}
GetFulfillmentPreviewRequest : The request body schema for the getFulfillmentPreview operation.

Fields

marketplace_id: Option<String>

The marketplace the fulfillment order is placed against.

address: Box<Address>items: Vec<GetFulfillmentPreviewItem>

An array of fulfillment preview item information.

shipping_speed_categories: Option<Vec<ShippingSpeedCategory>>include_cod_fulfillment_preview: Option<bool>

Specifies whether to return fulfillment order previews that are for COD (Cash On Delivery). Possible values: * true - Returns all fulfillment order previews (both for COD and not for COD). * false - Returns only fulfillment order previews that are not for COD.

include_delivery_windows: Option<bool>

Specifies whether to return the ScheduledDeliveryInfo response object, which contains the available delivery windows for a Scheduled Delivery. The ScheduledDeliveryInfo response object can only be returned for fulfillment order previews with ShippingSpeedCategories = ScheduledDelivery.

feature_constraints: Option<Vec<FeatureSettings>>

A list of features and their fulfillment policies to apply to the order.

Implementations

The request body schema for the getFulfillmentPreview operation.